<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>Copia de</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Cada turno</numerusform>
            <numerusform>Cada %1 turnos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Editar armas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Set de armas ilegal</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Editar modos de juego</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon (and viceversa)</source>
        <translation type="obsolete">Cuando esta opción esté activada escoger un modo de juego escogerá el set de armas correspondiente (y viceversa)</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation>Cuando esta opción esté activada escoger un modo de juego escogerá el set de armas correspondiente</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 ha sido eliminado de tu lista de ignorados</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 has sido añadido a tu lista de ignorados</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 ha sido eliminado de tu lista de amigos</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 ha sido añadido a tu lista de amigos</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>No se pudo iniciar el servidor</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>No se pudo almacenar una entrada en el fichero %1</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="obsolete">Nuevo</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Por favor, selecciona una entrada de la lista</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation>Equipo predeterminado</translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation>Fichero de demo de Hedgewars</translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation>Partida guardada de Hedgewars</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>es.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>No se pudo abrir la demo %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeño</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mediano</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Caverna</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Lunático</translation>
    </message>
    <message>
        <source>Tunnel size</source>
        <translation type="obsolete">Tamaño del túnel</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Túneles estrechos</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Túneles normales</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Túneles anchos</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Islas pequeñas</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Islas medianas</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Islas grandes</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation>Semilla</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished">Establecer</translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>No se pudo establecer una conexión con el servidor. Por favor, comprueba que el nombre del servidor y el puerto son correctos.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>La conexión fue rechazada</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Motivo:</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Sala eliminada</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Has sido expulsado</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">El nick %1 ya está
registrado en Hedgewars.org
Por favor, introduce tu clave
o elige otro nick:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 ha entrado en la sala</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 ha entrado</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 ha salido (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 ha salido</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation>El nick %1 ya está registrado 
en Hedgewars.org. Por favor,
introduce ahora tu clave de acceso
o elige otro nick en las preferencias del juego:</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf ha devuelto un error al dibujar texto, probablemente relacionado con un bug en freetype2. Se recomienda actualizar la librería freetype.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Mensaje del servidor:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Establecer mensaje</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Vaciar caché de cuentas</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>Obtener datos</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>Mensaje del servidor para la última versión:</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>Mensaje del servidor para versiones anteriores:</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>Número de protocolo de la última versión:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>Vista previa del MOTD:</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>Enviar datos</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation>Cargar mapa</translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation>Mapas dibujados a mano (*.hwmap);;Todos los ficheros (*.*)</translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation>Guardar mapa</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;El premio al mejor disparo es para &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; puntos.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;El asesino más eficiente es &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; muerte en un solo turno.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;El asesino más eficiente es &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; muertes en un solo turno.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Un total de &lt;b&gt;%1&lt;/b&gt; erizo murió esta ronda.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Un total de &lt;b&gt;%1&lt;/b&gt; erizos murieron esta ronda.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation>Gráfica de puntos de vida</translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation>Clasificación</translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>El premio al mejor disparo es para &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; pts.</translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation>
            <numerusform>El mejor guerrero es &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; muerte en un solo turno.</numerusform>
            <numerusform>El mejor guerrero es &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; muertes en un solo turno.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation>
            <numerusform>Un total de &lt;b&gt;%1&lt;/b&gt; erizo murió esta ronda.</numerusform>
            <numerusform>Un total de &lt;b&gt;%1&lt;/b&gt; erizos murieron esta ronda.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation>
            <numerusform>(%1 baja)</numerusform>
            <numerusform>(%1 bajas)</numerusform>
        </translation>
    </message>
    <message>
        <source>(%1 kills)</source>
        <translation type="obsolete">(%1 bajas)</translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; prefiere disparar a sus miembros, con un total de &lt;b&gt;%2&lt;/b&gt; pt.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; prefiere disparar a sus miembros, con un total de &lt;b&gt;%2&lt;/b&gt; pts.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; acabó con &lt;b&gt;%2&lt;/b&gt; de sus propios miembros.</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; tenía demasiado miedo y pasó &lt;b&gt;%2&lt;/b&gt; turno.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; tenía demasiado miedo y pasó &lt;b&gt;%2&lt;/b&gt; turnos.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Juego local (Jugar en la misma computadora)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Juego en red (Jugar a través de la red)</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation>Elige el mismo color que tus amigos para hacer una alianza con ellos. Cada uno de vosotros controlará sus propios erizos, pero la victoria o derrota será compartida por vuestra facción.</translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation>Puede que algunas armas hagan poco daño, pero pueden ser realmente devastadoras si son usadas en el momento correcto. Prueba a usar la Desert eagle para empujar erizos enemigos al agua, por ejemplo.</translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation>Si no tienes claro qué vas a hacer y prefieres no desperdiciar munición puedes pasar un turno. ¡Pero ten cuidado, si dejas pasar muchos turnos puede que empiece la muerte súbita!</translation>
    </message>
    <message>
        <source>Want to save ropse? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="obsolete">¿Andas escaso de cuerdas? Suelta la cuerda mientras estés en el aire y vuelve a dispararla de nuevo. ¡Mientras no toques el suelo seguirás usando la misma cuerda sin desperdiciar munición adicional!</translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation>Si prefieres que nadie más use tu nick en el servidor oficial puedes registrarlo en http://www.hedgewars.org/.</translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation>¿Estás cansado del modo de juego de siempre? Prueba alguna de las misiones, encontrarás en ellas nuevos tipos de juego dependiendo de la que elijas.</translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation>El juego intentará guardar la última partida como una demo de forma predeterminada. Más tarde puedes ir a &quot;Juego local&quot; y visitar la sección de &quot;Demos&quot; en la esquina inferior derecha para reproducirlas o gestionarlas.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation>Hedgewars es un juego gratuito de código abierto que hemos creado en nuestro tiempo libre. Si tienes algún problema estaremos encantados de ayudarte en nuestros foros o canal de IRC, pero ¡no esperes que estemos allí las 24 horas del día!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation>Hedgewars es un juego gratuito de código abierto que hemos creado en nuestro tiempo libre. ¡Si te gusta podrías considerar el ayudarnos con una pequeña donación o contribuyendo con tu propio trabajo!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation>Hedgewars es un juego gratuito de código abierto que hemos creado en nuestro tiempo libre. ¡Compártelo con tu família y amigos tanto como quieras!</translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation>De cuando en cuando celebramos torneos oficiales. Puedes mantenerte al día sobre los próximos eventos en http://www.hedgewars.org.</translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation>Hedgewars está disponible en varios idiomas. Si no encuentras traducción a tu idioma o piensas que la actual es de baja calidad o está desactualizada estaremos encantados de aceptar tu colaboración para mejorarla.</translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation>Hedgewars es un juego multiplataforma que puede ser ejecutado en diversos sistemas operativos, incluyendo Windows, Mac OS X y Linux.</translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation>Recuerda: puedes crear tus propias partidas multijugador tanto en local como por red, no estás limitado a jugar contra la máquina.</translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation>Tu salud es lo primero. Recuerda descansar unos minutos al menos una vez por cada hora de juego.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation>Si tu tarjeta gráfica no soporta aceleración gráfica mediante OpenGL prueba a habilitar el modo de baja calidad gráfica en la pantalla de opciones, puede que mejore el rendimiento del juego.</translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation>Siempre estamos abiertos a sugerencias y opiniones constructivas. Si hay algo que no te guste o tienes grandes ideas que te gustaría ver en el juego, ¡háznoslo saber!</translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation>Si juegas a través de internet recuerda mantener tus buenos modales y siempre ten en cuenta que puede que estés jugando con o contra menores de edad.</translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation>Los modos de juego especiales como &quot;vampirismo&quot; o &quot;karma&quot; te permiten desarrollar tácticas de juego completamente nuevas. ¡Pruébalos en tu próxima partida!</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation>La versión para Windows de Hedgewars soporta Xfire. Recuerda añadie Hedgewars a tu lista de juegos favoritos para que tus amigos sepan cuándo estás jugando.</translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation>¡Nunca instales Hedgewars en ordenadores que no te pertenezcan tales como los de tu escuela, universidad o trabajo sin perdir permiso primero a las personas responsables de los mismos!</translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation>Hedgewars es realmente genial para jugar partidas rápidas durante pausas o descansos; sólo recuerda no añadir muchos erizos y no usar mapas excesivamente grandes para que la partida no se alargue demasiado. Reducir la duración de los turnos o la vida inicial también puede ayudar.</translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation>Ningún erizo fue lastimado durante la creación de este juego.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation>Hedgewars es un juego gratuito de código abierto que hemos creado en nuestro tiempo libre. Si alguien te ha vendido el juego deberías pedirle que te devuelva tu dinero.</translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation>Conecta tus mandos al ordenador antes de iniciar el juego para poder asignar correctamente los controles de a equipo.</translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation>Crea una cuenta con tu nick en %1 para evitar que otras personas puedan usarlo en el servidor oficial.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation>Si tu tarjeta gráfica no es capaz de usar aceleración gráfica mediante OpenGL prueba a instalar drivers más actualizados.</translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation>Hay tres tipos de salto en el juego. Presiona [salto alto] dos veces para realizar un salto muy alto, vertical y ligeramente hacia atrás.</translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation>¿Te da miedo caerte por una cornisa? Mantén presionado [aumentar precisión] para voltearte a [izquierda] o [derecha] sin moverte del sitio.</translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation>Algunas armas pueden requerir estrategias especiales o mucho entrenamiento antes de ser usadas correctamente. No tires la a toalla con alguna de ellas sólo porque has fallado el tiro la primera vez.</translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation>La mayoría de armas se desactivarán al tocar el agua. El abejorro y la tarta son algunas de las excepciones a la regla.</translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation>La explosión del limbuger añejo es relativamente pequeña, pero produce una nube de gas venenoso que será arrastrada por el viento, siendo capaz de intoxicar a varios erizos a la vez.</translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation>El piano es el ataque aéreo más destructivo del juego, aunque perderás el erizo que lo lance, así que úsalo con cuidado.</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation>El abejorro puede ser complicado de usar. Su maniobrabilidad depende de su velocidad, así que intenta no lanzarlo a máxima potencia.</translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation>Las bombas lapa son perfectas para crear reacciones en cadena y mandar a tus enemigos al agua... o la Luna.</translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation>El mazo es mucho más efectivo si lo usas sobre vigas o puentes. Los erizos golpeados simplemente caerán por el agujero como Alicia por la madriguera.</translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation>Si estás atrapado tras un erizo enemigo puedes usar el mazo para abrirte paso sin resultar dañado por una explosión.</translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation>El alcance de la tarta depende de lo escarpado del terreno que tenga que atravesar, aunque puedes pulsar [atacar] para detonarla antes de que el contador llegue a cero.</translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation>El lanzallamas es un arma, pero puede usarse para excavar túneles en caso de necesidad.</translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation>Puedes usar el cóctel molotov para evitar que erizos enemigos crucen túneles angostos o puentes.</translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation>¿Quieres saber quiénes son los desarrolladores del juego? Pulsa el logo del juego en la pantalla principal para ver los créditos.</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation>¿Te gusta Hedgewars? ¡Hazte fan en %1 o síguenos en %2!</translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation>¡Puedes dibujar tus propias tumbas, sombreros, banderas o incluso mapas y temas! Sólo ten en cuenta que el juego no es capaz de enviar archivos todavía, así que tendrás que enviar tú mismo los archivos a tus amigos para poder jugar en red con ellos.</translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation>¿Te gustaría poder usar un sombrero especial, sólo para ti? Haz una donación y dinos qué sombrero quieres, lo dibujaremos para ti.</translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation>Mantén los drivers de tu tarjeta gráfica actualizados para evitar posibles problemas con este y otros juegos.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Puedes encontrar los archivos de configuración del juego en la carpeta &quot;Mis Documentos\Hedgewars&quot;. Haz copias de seguridad de los mismos o cópialos a otro ordenador si lo deseas, pero no intentes editarlos a mano para evitar posibles pérdidas de datos.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Puedes encontrar los archivos de configuración del juego en la carpeta ~/.hedgewars. Haz copias de seguridad de los mismos o cópialos a otro ordenador si lo deseas, pero no intentes editarlos a mano para evitar posibles pérdidas de datos.</translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation>Puedes asociar los tipos de archivo relacionados, partidas guardadas y demos, con Hedgewars para lanzarlos directamente desde tu gestor de archivos o navegador favoritos.</translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation>¿Necesitas conservar cuerdas? Cuando estés usando una cuerda puedes desengancharla y volver a lanzarla de nuevo. ¡Mientras no toques el suelo seguirás usando la misma cuerda continuamente sin desperdiciar munición adicional!</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Puedes encontrar los archivos de configuración del juego en la carpeta &quot;Library/Application Support/Hedgewars&quot; dentro de tu directorio personal. Puedes hacer copias de seguridad de los mismos o copiarlos a otro ordenador si lo deseas, pero no intentes editarlos a mano para evitar posibles pérdidas de datos.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Puedes encontrar los archivos de configuración del juego en la carpeta &quot;.hedgewars&quot; dentro de tu directorio personal. Puedes hacer copias de seguridad de los mismos o copiarlos a otro ordenador si lo deseas, pero no intentes editarlos a mano para evitar posibles pérdidas de datos.</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Empezar</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Por favor, selecciona un servidor de la lista</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Opciones</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>Red local</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Servidor oficial</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Nuevo equipo</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Editar equipo</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Borrar equipo</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="obsolete">Nuevo set de armas</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="obsolete">Editar set de armas</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="obsolete">Borrar set de armas</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation>No es posible editar equipos desde la pantalla de elección de equipo. Vuelve al menú principal para añadir, editar o borrar equipos.</translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation>Nuevo modo de juego</translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation>Editar modo de juego</translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation>Eliminar modo de juego</translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation>Nuevo set de armas</translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation>Editar set de armas</translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation>Eliminar set de armas</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Introduce el nuevo nombre del fichero:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>No se pudo cambiar el nombre a</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>No se pudo eliminar el fichero</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Por favor, selecciona una entrada de la lista</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Crear</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Parámetros del administrador</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Nombre de la sala:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Este juego está en espera
Puedes entrar y empezar a jugar cuando la partida comience.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Esta partida se encuentra en progreso
Puedes unirte como espectador, pero tendrás que esperar a que el juego termine para poder jugar.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 es el anfitrión. Puede ajustar los parámetros del juego e iniciar la partida.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Terreno aleatorio</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Las partidas pueden ser jugadas bien en mapas pre-creados o generados aleatoriamente.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Los modos de juego definen opciones generales y preferencias como el tiempo de las rondas, muerte súbita o vampirismo.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>El set de armas define las armas y munición disponibles.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>Hay %1 cliente en esta sala.</numerusform>
            <numerusform>Hay %1 clientes en esta sala.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>Hay %1 equipo participando en esta sala.</numerusform>
            <numerusform>Hay %1 equipos participando en esta sala.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Por favor, introduce un nombre para la sala</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Por favor, selecciona una sala de la lista</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Laberinto aleatorio</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation>Reglas:</translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation>Armas:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Búsqueda:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation>La partida a la que intentas unirte ya ha empezado.
¿Realmente deseas entrar en la sala?</translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">Habilitar minas aleatorias</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Recuperar el 80% del daño infligido como vida</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Comparte el dolor de tus enemigos, comparte su daño</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Tus erizos no podrán moverse, pon tu puntería a prueba</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatorio</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Defiende tu fuerte y destruye el de tus oponentes. ¡2 facciones como máximo!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Los equipos comenzarán en lados opuestos del terreno. ¡2 facciones como máximo!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>¡El terreno es indestructible!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Añade un borde indestructible alrededor del campo de juego</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Baja gravedad</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Una mira láser que te ayudará a apuntar</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Todos los erizos tienen un campo de fuerza personal que los protege</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>El orden de los equipos en la partida es aleatorio en lugar de tal como se muestran en la sala.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>El primero erizo del equipo es el Rey. Tu equipo pierde el juego si el rey muere, así que protégelo.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Los jugadores posicionan a mano su erizos por turnos antes de empezar a jugar.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>La munición se comparte entre los equipos de una misma facción.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Deshabilita las vigas en los mapas generados aleatoriamente.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>Deshabilita los objetos en los mapas generados aleatoriamente.</translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation>La computadora resucita al morir.</translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation>Atacar no terminará tu turno.</translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation>La munición será reiniciada al comienzo de cada turno.</translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation>Cada erizo tiene su propia munición y no la comparte con el resto del equipo.</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation>La salud de todos los erizos en pie es restaurada al final de cada turno</translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation>No tendrás que volver a preocuparte del viento.</translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation>El viento afectará a (casi) todo.</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Partida sencilla (Una partida rápida contra la computadora; los ajustes se eligen automáticamente)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Multijugador (Juega compartiendo el ordenador contra tus amigos o la computadora)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Entrenamiento (Practica tus habilidades en diversas misiones de entrenamiento). EN DESARROLLO</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demos (Visualiza demos previamente grabadas)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Cargar (Cargar un juego previamente guardado)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation>Campaña (...) EN DESARROLLO</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Expulsar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Empezar</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Impedir que entren más jugadores</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Impedir que se añadan más equipos</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Banear</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Vigilar</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Añadir amigo</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Desbloquear</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Eliminar amigo</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Habilitar sonidos del juego</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Mostrar FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Mostrar el daño según ocurre</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Habilitar música del juego</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Interfaz a pantalla completa</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Agregar fecha y hora al nombre de los ficheros</translation>
    </message>
    <message>
        <source>Check for updates at startup</source>
        <translation>Comprobar actualizaciones al iniciar</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">Reducir efectos gráficos (para ordenadores lentos)</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Mostrar globos de ayuda sobre el armamento</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Habilitar sonidos del interfaz</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Habilitar música del interfaz</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Habilitar efectos del interfaz</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>Terreno aleatorio...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Humano</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Predeterminado del sistema)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>Laberinto aleatorio...</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Misión</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>Comunidad</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Cualquiera</translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation>En espera</translation>
    </message>
    <message>
        <source>In progress</source>
        <translation>En progreso</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Predeterminado</translation>
    </message>
    <message>
        <source>Pro mode</source>
        <translation type="obsolete">Modo pro</translation>
    </message>
    <message>
        <source>Shoppa</source>
        <translation type="obsolete">Shoppa</translation>
    </message>
    <message>
        <source>Basketball</source>
        <translation type="obsolete">Baloncesto</translation>
    </message>
    <message>
        <source>Minefield</source>
        <translation type="obsolete">Campo de minas</translation>
    </message>
    <message>
        <source>Barrel mayhem</source>
        <translation type="obsolete">Bodega infernal</translation>
    </message>
    <message>
        <source>Tunnel hogs</source>
        <translation type="obsolete">Erizos subterráneos</translation>
    </message>
    <message>
        <source>Crazy</source>
        <translation type="obsolete">Lunático</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Normal</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation>Mapa dibujado a mano...</translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Miembros del equipo</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Asociaciones de teclas</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Fuerte</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Equipos</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Opciones de Audio y Gráficos</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Sets de armas</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Juego en red</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Equipos participantes</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Modificadores</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Opciones básicas</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Opciones del equipo</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Otras opciones</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation>Modos de juego y sets de armas</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Este programa está distribuido bajo la licencia GNU General Public License</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Desarrolladores:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Gráficos:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Traducciones:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Agradecimientos:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Set de armas</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Anfitrión:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Puerto:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>Límite de FPS</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Apodo</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Nombre del servidor:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Puerto del servidor:</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Sonidos:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Volumen de sonido por defecto</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Modificador al daño</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Duración del turno</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Vida inicial</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Turnos hasta muerte súbita</translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation>Temporizador de las minas</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Minas</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Nombre del modo de juego:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Aparición de cajas</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Modo de juego</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% minas defectuosas</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Lápida</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Bandera</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voz</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Requiere reiniciar el juego</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="obsolete">Esta es una versión experimental del juego y puede no ser compatible con otras versiones del mismo,
así como carecer de algunas funcionalidades o simplemente funcionar mal. 
¡Úsalo bajo tu propia responsalibidad!</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Explosivos</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation>Consejo: </translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>Esta es una versión experimental del juego y puede no ser compatible con otras versiones del mismo,
así como carecer de algunas funcionalidades o simplemente funcionar mal. 
¡Úsalo bajo tu propia responsabilidad!</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation>% botiquines</translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation>Vida en botiquines</translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation>Aumento del nivel del agua en muerte súbita</translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation>Disminución de vida por turno en muerte súbita</translation>
    </message>
    <message>
        <source>Bind schemes and weapons</source>
        <translation type="obsolete">Enlazar modos y sets</translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation>% longitud de las cuerdas</translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation>Tipo de juego</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>sin nombre</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Se perdió la conexión con el servidor</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>No de pudo abrir el directorio:
%1
Por favor, compruebe que el juego está debidamente instalado</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Sets de armas</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">No se puede editar el set de armas predefinido</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">No se puede borrar el set de armas predefinido</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>¿Realmente quieres borrar este set de armas?</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation>¡No se puede sobreescribir el set de armas por defecto &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation>Se reestablecieron todas las asociaciones de tipo de archivo.</translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation>No se pudieron asociar los tipos de fichero.</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Equipos</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation>¿De verdad quieres eliminar este equipo?</translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation>Modos de juego</translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation>¡No se puede eliminar el modo de juego predefinido &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation>¿De verdad quieres eliminar este modo de juego?</translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation>¡No se puede eliminar el set de armas predefinido &apos;%1&apos;!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>No se pudo crear el directorio %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Por favor introduce tu nick</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Go!</source>
        <translation>¡Adelante!</translation>
    </message>
    <message>
        <source>default</source>
        <translation>predeterminado</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Iniciar servidor</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Especificar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Empezar</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Reproducir demo</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Equipo aleatorio</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation>Asociar tipos de archivo</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="obsolete">Establecer</translation>
    </message>
    <message>
        <source>more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Nombre de la sala</translation>
    </message>
    <message>
        <source>C</source>
        <translation>J</translation>
    </message>
    <message>
        <source>T</source>
        <translation>E</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Propietario</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Reglas</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Set de armas</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Cantidad inicial</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Probabilidades</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Munición en las cajas</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Retraso</translation>
    </message>
    <message>
        <source>new</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>Copia de</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>No se pudo iniciar el servidor: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>No se pudo iniciar el motor: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampirismo</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Artillería</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Fuertes</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Separar equipos</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Terreno indestructible</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Añadir borde</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Baja gravedad</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Mira láser</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Invulnerabilidad</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">Añadir minas</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Orden aleatorio</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Rey</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Posicionar erizos</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Compartir munición</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Deshabilitar vigas</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>Deshabilitar decoraciones</translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation>Supervivencia contra la computadora</translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation>Ataques ilimitados</translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation>Reiniciar munición</translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation>Munición individualizada</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation>Restaurar salud</translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation>Deshabilitar viento</translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation>Más viento</translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>arriba</translation>
    </message>
    <message>
        <source>left</source>
        <translation>izquierda</translation>
    </message>
    <message>
        <source>right</source>
        <translation>derecha</translation>
    </message>
    <message>
        <source>down</source>
        <translation>abajo</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>atacar</translation>
    </message>
    <message>
        <source>put</source>
        <translation>usar</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>cambiar</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>buscar erizo</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>menú de armamento</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>posición 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>posición 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>posición 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>posición 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>posición 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>posición 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>posición 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>posición 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>posición 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>temporizador 1 sec</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>temporizador 2 sec</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>temporizador 3 sec</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>temporizador 4 sec</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>temporizador 5 sec</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pausa</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>disminuir volumen</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>aumentar volumen</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>cambiar modo</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>capturar</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>información de
los erizos</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>salir</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>conversación</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>historial de conversación</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>confirmación</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>aumentar precisión</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>acercar</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>alejar</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>reiniciar zoom</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>salto largo</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>salto alto</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation>posición 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Controles básicos</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Armas</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Cámara y cursor</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Otros</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Mueve tus erizos y apunta:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Sortea huecos y obstáculos saltando:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Dispara el arma seleccionada o usa una herramienta:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Selecciona un arma o un objetivo bajo el cursor:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Cambia tu erizo activo (si es posible):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Selecciona un arma o herramienta:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Establece el temporizador de bombas y armas temporizadas:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Centra la cámara en el erizo activo:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Mueve el cursor o la cámara sin usar el ratón:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Modifica el nivel de zoom de la cámara:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Habla con tu equipo o el resto de participantes:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pausa, continúa o sal del juego:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Modifica el volumen mientras juegas:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Cambiar a/desde modo de pantalla completa:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Toma una captura de pantalla:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Cambia las etiquetas sobre los erizos:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Eje</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Arriba)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Abajo)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Sombrero</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Izquierda)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Derecha)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Botón</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Teclado</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Ratón: botón izquierdo</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Ratón: botón central</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Ratón: botón derecho</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Ratón: rueda arriba</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Ratón: rueda abajo</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Retroceso</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tabulador</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Supr</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Intro</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Barra espaciadora</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supr</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Teclado numérico 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Teclado numérico 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Teclado numérico 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Teclado numérico 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Teclado numérico 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Teclado numérico 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Teclado numérico 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Teclado numérico 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Teclado numérico 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Teclado numérico 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Teclado numérico .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Teclado numérico /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Teclado numérico *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Teclado numérico -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Teclado numérico +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Intro</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>Igual</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insert</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Re Pág</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Av Pág</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Bloq Num</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Bloq Mayús</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Bloq Despl</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Shift derecho</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Shift izquierdo</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Ctrl derecho</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Ctrl izquierdo</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Alt Gr</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Meta derecho</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Meta izquierdo</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>Botón A</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>Botón B</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>Botón X</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Botón Y</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>Botón LB</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>Botón RB</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Botón atrás</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Botón Start</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Palanca izquierda</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Palanca derecha</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Palanca izquierda (derecha)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Palanca izquierda (izquierda)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Palanca izquierda (abajo)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Palanca izquierda (arriba)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Gatillo izquierdo</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Gatillo derecho</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Palanca derecha (abajo)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Palanca derecha (arriba)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Palanca derecha (derecha)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Palanca derecha (izquierda)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad</translation>
    </message>
</context>
</TS>
